
USE [Contacts]
GO

/****** Object:  StoredProcedure [usp_CityRefLoadByPrimaryKey]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_CityRefLoadByPrimaryKey]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_CityRefLoadByPrimaryKey];
GO

CREATE PROCEDURE [usp_CityRefLoadByPrimaryKey]
(
	@ZipCode char(5)
)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[CityName],
		[State],
		[ZipCode],
		[ZipPlus4],
		[FullZip]
	FROM [CityRef]
	WHERE
		([ZipCode] = @ZipCode)

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_CityRefLoadByPrimaryKey Succeeded'
ELSE PRINT 'Procedure Creation: usp_CityRefLoadByPrimaryKey Error on Creation'
GO

/****** Object:  StoredProcedure [usp_CityRefLoadAll]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_CityRefLoadAll]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_CityRefLoadAll];
GO

CREATE PROCEDURE [usp_CityRefLoadAll]
AS
BEGIN

	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[CityName],
		[State],
		[ZipCode],
		[ZipPlus4],
		[FullZip]
	FROM [CityRef]

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_CityRefLoadAll Succeeded'
ELSE PRINT 'Procedure Creation: usp_CityRefLoadAll Error on Creation'
GO

/****** Object:  StoredProcedure [usp_CityRefUpdate]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_CityRefUpdate]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_CityRefUpdate];
GO

CREATE PROCEDURE [usp_CityRefUpdate]
(
	@CityName varchar(50),
	@State char(2),
	@ZipCode char(5),
	@ZipPlus4 char(4) = NULL,
	@FullZip varchar(10) = NULL output
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	UPDATE [CityRef]
	SET
		[CityName] = @CityName,
		[State] = @State,
		[ZipPlus4] = @ZipPlus4
	WHERE
		[ZipCode] = @ZipCode


	SET @Err = @@Error

    SELECT @FullZip = [FullZip]
      FROM [CityRef]
     WHERE [ZipCode] = @ZipCode


	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_CityRefUpdate Succeeded'
ELSE PRINT 'Procedure Creation: usp_CityRefUpdate Error on Creation'
GO




/****** Object:  StoredProcedure [usp_CityRefInsert]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_CityRefInsert]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_CityRefInsert];
GO

CREATE PROCEDURE [usp_CityRefInsert]
(
	@CityName varchar(50),
	@State char(2),
	@ZipCode char(5),
	@ZipPlus4 char(4) = NULL,
	@FullZip varchar(10) = NULL output
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	INSERT
	INTO [CityRef]
	(
		[CityName],
		[State],
		[ZipCode],
		[ZipPlus4]
	)
	VALUES
	(
		@CityName,
		@State,
		@ZipCode,
		@ZipPlus4
	)

	SET @Err = @@Error


    SELECT @FullZip = [FullZip]
      FROM [CityRef]
     WHERE [ZipCode] = @ZipCode

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_CityRefInsert Succeeded'
ELSE PRINT 'Procedure Creation: usp_CityRefInsert Error on Creation'
GO

/****** Object:  StoredProcedure [usp_CityRefDelete]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_CityRefDelete]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_CityRefDelete];
GO

CREATE PROCEDURE [usp_CityRefDelete]
(
	@ZipCode char(5)
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	DELETE
	FROM [CityRef]
	WHERE
		[ZipCode] = @ZipCode
	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_CityRefDelete Succeeded'
ELSE PRINT 'Procedure Creation: usp_CityRefDelete Error on Creation'
GO

/****** Object:  StoredProcedure [usp_ConferenceLoadByPrimaryKey]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_ConferenceLoadByPrimaryKey]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_ConferenceLoadByPrimaryKey];
GO

CREATE PROCEDURE [usp_ConferenceLoadByPrimaryKey]
(
	@ConferenceId int
)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[ConferenceId],
		[LeagueId],
		[ConferenceName]
	FROM [Conference]
	WHERE
		([ConferenceId] = @ConferenceId)

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_ConferenceLoadByPrimaryKey Succeeded'
ELSE PRINT 'Procedure Creation: usp_ConferenceLoadByPrimaryKey Error on Creation'
GO

/****** Object:  StoredProcedure [usp_ConferenceLoadAll]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_ConferenceLoadAll]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_ConferenceLoadAll];
GO

CREATE PROCEDURE [usp_ConferenceLoadAll]
AS
BEGIN

	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[ConferenceId],
		[LeagueId],
		[ConferenceName]
	FROM [Conference]

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_ConferenceLoadAll Succeeded'
ELSE PRINT 'Procedure Creation: usp_ConferenceLoadAll Error on Creation'
GO

/****** Object:  StoredProcedure [usp_ConferenceUpdate]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_ConferenceUpdate]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_ConferenceUpdate];
GO

CREATE PROCEDURE [usp_ConferenceUpdate]
(
	@ConferenceId int,
	@LeagueId int = NULL,
	@ConferenceName varchar(50) = NULL
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	UPDATE [Conference]
	SET
		[LeagueId] = @LeagueId,
		[ConferenceName] = @ConferenceName
	WHERE
		[ConferenceId] = @ConferenceId


	SET @Err = @@Error


	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_ConferenceUpdate Succeeded'
ELSE PRINT 'Procedure Creation: usp_ConferenceUpdate Error on Creation'
GO




/****** Object:  StoredProcedure [usp_ConferenceInsert]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_ConferenceInsert]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_ConferenceInsert];
GO

CREATE PROCEDURE [usp_ConferenceInsert]
(
	@ConferenceId int = NULL output,
	@LeagueId int = NULL,
	@ConferenceName varchar(50) = NULL
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	INSERT
	INTO [Conference]
	(
		[LeagueId],
		[ConferenceName]
	)
	VALUES
	(
		@LeagueId,
		@ConferenceName
	)

	SET @Err = @@Error

	SELECT @ConferenceId = SCOPE_IDENTITY()

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_ConferenceInsert Succeeded'
ELSE PRINT 'Procedure Creation: usp_ConferenceInsert Error on Creation'
GO

/****** Object:  StoredProcedure [usp_ConferenceDelete]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_ConferenceDelete]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_ConferenceDelete];
GO

CREATE PROCEDURE [usp_ConferenceDelete]
(
	@ConferenceId int
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	DELETE
	FROM [Conference]
	WHERE
		[ConferenceId] = @ConferenceId
	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_ConferenceDelete Succeeded'
ELSE PRINT 'Procedure Creation: usp_ConferenceDelete Error on Creation'
GO

/****** Object:  StoredProcedure [usp_ContactsLoadByPrimaryKey]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_ContactsLoadByPrimaryKey]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_ContactsLoadByPrimaryKey];
GO

CREATE PROCEDURE [usp_ContactsLoadByPrimaryKey]
(
	@ContactId int
)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[ContactId],
		[FirstName],
		[MiddleName],
		[LastName],
		[HomeNumber],
		[WorkNumber],
		[MobileNumber],
		[Email1],
		[Email2],
		[Email3],
		[Address1],
		[Address2],
		[CityName],
		[State],
		[ZipCode],
		[ZipPlus4],
		[TeamId]
	FROM [Contacts]
	WHERE
		([ContactId] = @ContactId)

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_ContactsLoadByPrimaryKey Succeeded'
ELSE PRINT 'Procedure Creation: usp_ContactsLoadByPrimaryKey Error on Creation'
GO

/****** Object:  StoredProcedure [usp_ContactsLoadAll]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_ContactsLoadAll]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_ContactsLoadAll];
GO

CREATE PROCEDURE [usp_ContactsLoadAll]
AS
BEGIN

	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[ContactId],
		[FirstName],
		[MiddleName],
		[LastName],
		[HomeNumber],
		[WorkNumber],
		[MobileNumber],
		[Email1],
		[Email2],
		[Email3],
		[Address1],
		[Address2],
		[CityName],
		[State],
		[ZipCode],
		[ZipPlus4],
		[TeamId]
	FROM [Contacts]

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_ContactsLoadAll Succeeded'
ELSE PRINT 'Procedure Creation: usp_ContactsLoadAll Error on Creation'
GO

/****** Object:  StoredProcedure [usp_ContactsUpdate]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_ContactsUpdate]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_ContactsUpdate];
GO

CREATE PROCEDURE [usp_ContactsUpdate]
(
	@ContactId int,
	@FirstName varchar(255) = NULL,
	@MiddleName varchar(255) = NULL,
	@LastName varchar(255) = NULL,
	@HomeNumber char(13) = NULL,
	@WorkNumber char(13) = NULL,
	@MobileNumber char(13) = NULL,
	@Email1 varchar(255) = NULL,
	@Email2 varchar(255) = NULL,
	@Email3 varchar(255) = NULL,
	@Address1 varchar(255) = NULL,
	@Address2 varchar(255) = NULL,
	@CityName varchar(255) = NULL,
	@State char(2) = NULL,
	@ZipCode char(5) = NULL,
	@ZipPlus4 char(4) = NULL,
	@TeamId int = NULL
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	UPDATE [Contacts]
	SET
		[FirstName] = @FirstName,
		[MiddleName] = @MiddleName,
		[LastName] = @LastName,
		[HomeNumber] = @HomeNumber,
		[WorkNumber] = @WorkNumber,
		[MobileNumber] = @MobileNumber,
		[Email1] = @Email1,
		[Email2] = @Email2,
		[Email3] = @Email3,
		[Address1] = @Address1,
		[Address2] = @Address2,
		[CityName] = @CityName,
		[State] = @State,
		[ZipCode] = @ZipCode,
		[ZipPlus4] = @ZipPlus4,
		[TeamId] = @TeamId
	WHERE
		[ContactId] = @ContactId


	SET @Err = @@Error


	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_ContactsUpdate Succeeded'
ELSE PRINT 'Procedure Creation: usp_ContactsUpdate Error on Creation'
GO




/****** Object:  StoredProcedure [usp_ContactsInsert]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_ContactsInsert]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_ContactsInsert];
GO

CREATE PROCEDURE [usp_ContactsInsert]
(
	@ContactId int = NULL output,
	@FirstName varchar(255) = NULL,
	@MiddleName varchar(255) = NULL,
	@LastName varchar(255) = NULL,
	@HomeNumber char(13) = NULL,
	@WorkNumber char(13) = NULL,
	@MobileNumber char(13) = NULL,
	@Email1 varchar(255) = NULL,
	@Email2 varchar(255) = NULL,
	@Email3 varchar(255) = NULL,
	@Address1 varchar(255) = NULL,
	@Address2 varchar(255) = NULL,
	@CityName varchar(255) = NULL,
	@State char(2) = NULL,
	@ZipCode char(5) = NULL,
	@ZipPlus4 char(4) = NULL,
	@TeamId int = NULL
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	INSERT
	INTO [Contacts]
	(
		[FirstName],
		[MiddleName],
		[LastName],
		[HomeNumber],
		[WorkNumber],
		[MobileNumber],
		[Email1],
		[Email2],
		[Email3],
		[Address1],
		[Address2],
		[CityName],
		[State],
		[ZipCode],
		[ZipPlus4],
		[TeamId]
	)
	VALUES
	(
		@FirstName,
		@MiddleName,
		@LastName,
		@HomeNumber,
		@WorkNumber,
		@MobileNumber,
		@Email1,
		@Email2,
		@Email3,
		@Address1,
		@Address2,
		@CityName,
		@State,
		@ZipCode,
		@ZipPlus4,
		@TeamId
	)

	SET @Err = @@Error

	SELECT @ContactId = SCOPE_IDENTITY()

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_ContactsInsert Succeeded'
ELSE PRINT 'Procedure Creation: usp_ContactsInsert Error on Creation'
GO

/****** Object:  StoredProcedure [usp_ContactsDelete]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_ContactsDelete]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_ContactsDelete];
GO

CREATE PROCEDURE [usp_ContactsDelete]
(
	@ContactId int
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	DELETE
	FROM [Contacts]
	WHERE
		[ContactId] = @ContactId
	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_ContactsDelete Succeeded'
ELSE PRINT 'Procedure Creation: usp_ContactsDelete Error on Creation'
GO

/****** Object:  StoredProcedure [usp_DivisionLoadByPrimaryKey]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_DivisionLoadByPrimaryKey]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_DivisionLoadByPrimaryKey];
GO

CREATE PROCEDURE [usp_DivisionLoadByPrimaryKey]
(
	@DivisionId int
)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[DivisionId],
		[ConferenceId],
		[DivisionName]
	FROM [Division]
	WHERE
		([DivisionId] = @DivisionId)

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_DivisionLoadByPrimaryKey Succeeded'
ELSE PRINT 'Procedure Creation: usp_DivisionLoadByPrimaryKey Error on Creation'
GO

/****** Object:  StoredProcedure [usp_DivisionLoadAll]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_DivisionLoadAll]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_DivisionLoadAll];
GO

CREATE PROCEDURE [usp_DivisionLoadAll]
AS
BEGIN

	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[DivisionId],
		[ConferenceId],
		[DivisionName]
	FROM [Division]

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_DivisionLoadAll Succeeded'
ELSE PRINT 'Procedure Creation: usp_DivisionLoadAll Error on Creation'
GO

/****** Object:  StoredProcedure [usp_DivisionUpdate]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_DivisionUpdate]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_DivisionUpdate];
GO

CREATE PROCEDURE [usp_DivisionUpdate]
(
	@DivisionId int,
	@ConferenceId int = NULL,
	@DivisionName varchar(50) = NULL
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	UPDATE [Division]
	SET
		[ConferenceId] = @ConferenceId,
		[DivisionName] = @DivisionName
	WHERE
		[DivisionId] = @DivisionId


	SET @Err = @@Error


	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_DivisionUpdate Succeeded'
ELSE PRINT 'Procedure Creation: usp_DivisionUpdate Error on Creation'
GO




/****** Object:  StoredProcedure [usp_DivisionInsert]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_DivisionInsert]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_DivisionInsert];
GO

CREATE PROCEDURE [usp_DivisionInsert]
(
	@DivisionId int = NULL output,
	@ConferenceId int = NULL,
	@DivisionName varchar(50) = NULL
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	INSERT
	INTO [Division]
	(
		[ConferenceId],
		[DivisionName]
	)
	VALUES
	(
		@ConferenceId,
		@DivisionName
	)

	SET @Err = @@Error

	SELECT @DivisionId = SCOPE_IDENTITY()

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_DivisionInsert Succeeded'
ELSE PRINT 'Procedure Creation: usp_DivisionInsert Error on Creation'
GO

/****** Object:  StoredProcedure [usp_DivisionDelete]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_DivisionDelete]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_DivisionDelete];
GO

CREATE PROCEDURE [usp_DivisionDelete]
(
	@DivisionId int
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	DELETE
	FROM [Division]
	WHERE
		[DivisionId] = @DivisionId
	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_DivisionDelete Succeeded'
ELSE PRINT 'Procedure Creation: usp_DivisionDelete Error on Creation'
GO

/****** Object:  StoredProcedure [usp_LeagueLoadByPrimaryKey]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_LeagueLoadByPrimaryKey]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_LeagueLoadByPrimaryKey];
GO

CREATE PROCEDURE [usp_LeagueLoadByPrimaryKey]
(
	@LeagueId int
)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[LeagueId],
		[LeagueName]
	FROM [League]
	WHERE
		([LeagueId] = @LeagueId)

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_LeagueLoadByPrimaryKey Succeeded'
ELSE PRINT 'Procedure Creation: usp_LeagueLoadByPrimaryKey Error on Creation'
GO

/****** Object:  StoredProcedure [usp_LeagueLoadAll]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_LeagueLoadAll]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_LeagueLoadAll];
GO

CREATE PROCEDURE [usp_LeagueLoadAll]
AS
BEGIN

	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[LeagueId],
		[LeagueName]
	FROM [League]

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_LeagueLoadAll Succeeded'
ELSE PRINT 'Procedure Creation: usp_LeagueLoadAll Error on Creation'
GO

/****** Object:  StoredProcedure [usp_LeagueUpdate]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_LeagueUpdate]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_LeagueUpdate];
GO

CREATE PROCEDURE [usp_LeagueUpdate]
(
	@LeagueId int,
	@LeagueName varchar(50) = NULL
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	UPDATE [League]
	SET
		[LeagueName] = @LeagueName
	WHERE
		[LeagueId] = @LeagueId


	SET @Err = @@Error


	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_LeagueUpdate Succeeded'
ELSE PRINT 'Procedure Creation: usp_LeagueUpdate Error on Creation'
GO




/****** Object:  StoredProcedure [usp_LeagueInsert]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_LeagueInsert]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_LeagueInsert];
GO

CREATE PROCEDURE [usp_LeagueInsert]
(
	@LeagueId int = NULL output,
	@LeagueName varchar(50) = NULL
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	INSERT
	INTO [League]
	(
		[LeagueName]
	)
	VALUES
	(
		@LeagueName
	)

	SET @Err = @@Error

	SELECT @LeagueId = SCOPE_IDENTITY()

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_LeagueInsert Succeeded'
ELSE PRINT 'Procedure Creation: usp_LeagueInsert Error on Creation'
GO

/****** Object:  StoredProcedure [usp_LeagueDelete]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_LeagueDelete]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_LeagueDelete];
GO

CREATE PROCEDURE [usp_LeagueDelete]
(
	@LeagueId int
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	DELETE
	FROM [League]
	WHERE
		[LeagueId] = @LeagueId
	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_LeagueDelete Succeeded'
ELSE PRINT 'Procedure Creation: usp_LeagueDelete Error on Creation'
GO

/****** Object:  StoredProcedure [usp_StateRefLoadByPrimaryKey]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_StateRefLoadByPrimaryKey]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_StateRefLoadByPrimaryKey];
GO

CREATE PROCEDURE [usp_StateRefLoadByPrimaryKey]
(
	@State char(2)
)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[State],
		[StateName]
	FROM [StateRef]
	WHERE
		([State] = @State)

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_StateRefLoadByPrimaryKey Succeeded'
ELSE PRINT 'Procedure Creation: usp_StateRefLoadByPrimaryKey Error on Creation'
GO

/****** Object:  StoredProcedure [usp_StateRefLoadAll]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_StateRefLoadAll]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_StateRefLoadAll];
GO

CREATE PROCEDURE [usp_StateRefLoadAll]
AS
BEGIN

	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[State],
		[StateName]
	FROM [StateRef]

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_StateRefLoadAll Succeeded'
ELSE PRINT 'Procedure Creation: usp_StateRefLoadAll Error on Creation'
GO

/****** Object:  StoredProcedure [usp_StateRefUpdate]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_StateRefUpdate]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_StateRefUpdate];
GO

CREATE PROCEDURE [usp_StateRefUpdate]
(
	@State char(2),
	@StateName varchar(50)
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	UPDATE [StateRef]
	SET
		[StateName] = @StateName
	WHERE
		[State] = @State


	SET @Err = @@Error


	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_StateRefUpdate Succeeded'
ELSE PRINT 'Procedure Creation: usp_StateRefUpdate Error on Creation'
GO




/****** Object:  StoredProcedure [usp_StateRefInsert]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_StateRefInsert]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_StateRefInsert];
GO

CREATE PROCEDURE [usp_StateRefInsert]
(
	@State char(2),
	@StateName varchar(50)
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	INSERT
	INTO [StateRef]
	(
		[State],
		[StateName]
	)
	VALUES
	(
		@State,
		@StateName
	)

	SET @Err = @@Error


	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_StateRefInsert Succeeded'
ELSE PRINT 'Procedure Creation: usp_StateRefInsert Error on Creation'
GO

/****** Object:  StoredProcedure [usp_StateRefDelete]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_StateRefDelete]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_StateRefDelete];
GO

CREATE PROCEDURE [usp_StateRefDelete]
(
	@State char(2)
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	DELETE
	FROM [StateRef]
	WHERE
		[State] = @State
	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_StateRefDelete Succeeded'
ELSE PRINT 'Procedure Creation: usp_StateRefDelete Error on Creation'
GO

/****** Object:  StoredProcedure [usp_TeamLoadByPrimaryKey]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_TeamLoadByPrimaryKey]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_TeamLoadByPrimaryKey];
GO

CREATE PROCEDURE [usp_TeamLoadByPrimaryKey]
(
	@TeamId int
)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[TeamId],
		[DivisionId],
		[TeamName]
	FROM [Team]
	WHERE
		([TeamId] = @TeamId)

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_TeamLoadByPrimaryKey Succeeded'
ELSE PRINT 'Procedure Creation: usp_TeamLoadByPrimaryKey Error on Creation'
GO

/****** Object:  StoredProcedure [usp_TeamLoadAll]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_TeamLoadAll]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_TeamLoadAll];
GO

CREATE PROCEDURE [usp_TeamLoadAll]
AS
BEGIN

	SET NOCOUNT ON
	DECLARE @Err int

	SELECT
		[TeamId],
		[DivisionId],
		[TeamName]
	FROM [Team]

	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_TeamLoadAll Succeeded'
ELSE PRINT 'Procedure Creation: usp_TeamLoadAll Error on Creation'
GO

/****** Object:  StoredProcedure [usp_TeamUpdate]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_TeamUpdate]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_TeamUpdate];
GO

CREATE PROCEDURE [usp_TeamUpdate]
(
	@TeamId int,
	@DivisionId int = NULL,
	@TeamName varchar(50) = NULL
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	UPDATE [Team]
	SET
		[DivisionId] = @DivisionId,
		[TeamName] = @TeamName
	WHERE
		[TeamId] = @TeamId


	SET @Err = @@Error


	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_TeamUpdate Succeeded'
ELSE PRINT 'Procedure Creation: usp_TeamUpdate Error on Creation'
GO




/****** Object:  StoredProcedure [usp_TeamInsert]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_TeamInsert]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_TeamInsert];
GO

CREATE PROCEDURE [usp_TeamInsert]
(
	@TeamId int = NULL output,
	@DivisionId int = NULL,
	@TeamName varchar(50) = NULL
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	INSERT
	INTO [Team]
	(
		[DivisionId],
		[TeamName]
	)
	VALUES
	(
		@DivisionId,
		@TeamName
	)

	SET @Err = @@Error

	SELECT @TeamId = SCOPE_IDENTITY()

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_TeamInsert Succeeded'
ELSE PRINT 'Procedure Creation: usp_TeamInsert Error on Creation'
GO

/****** Object:  StoredProcedure [usp_TeamDelete]    Script Date: 4/26/2006 7:54:00 PM ******/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[usp_TeamDelete]') AND OBJECTPROPERTY(id,N'IsProcedure') = 1)
    DROP PROCEDURE [usp_TeamDelete];
GO

CREATE PROCEDURE [usp_TeamDelete]
(
	@TeamId int
)
AS
BEGIN

	SET NOCOUNT OFF
	DECLARE @Err int

	DELETE
	FROM [Team]
	WHERE
		[TeamId] = @TeamId
	SET @Err = @@Error

	RETURN @Err
END
GO


-- Display the status of Proc creation
IF (@@Error = 0) PRINT 'Procedure Creation: usp_TeamDelete Succeeded'
ELSE PRINT 'Procedure Creation: usp_TeamDelete Error on Creation'
GO
